@@ -8,7 +8,12 @@ function(resultlist_part, measurement_vector=NULL, time=NULL, height= NULL, lat=
 ## output: plots
 	if (resultlist_part$method == 'roc_static') {
 		filename<-paste(basename,"_",resultlist_part$element,"_",'roc_static',sep="")
-		qat_plot_roc_rule_static_1d(resultlist_part$result$flagvector, filename, measurement_vector=measurement_vector, max_upward_value=resultlist_part$result$max_upward_value, max_downward_value=resultlist_part$result$max_downward_value, measurement_name=measurement_name, directoryname=directoryname, plotstyle=plotstyle)
+		if (is.null(dim(resultlist_part$result$flagvector))) {	
+			qat_plot_roc_rule_static_1d(resultlist_part$result$flagvector, filename, measurement_vector=measurement_vector, max_upward_value=resultlist_part$result$max_upward_value, max_downward_value=resultlist_part$result$max_downward_value, measurement_name=measurement_name, directoryname=directoryname, plotstyle=plotstyle)
+		}
+		if (length(dim(resultlist_part$result$flagvector))==2) {	
+			qat_plot_roc_rule_static_2d(resultlist_part$result$flagvector, filename, measurement_vector=measurement_vector, max_upward_value=resultlist_part$result$max_upward_value, max_downward_value=resultlist_part$result$max_downward_value, measurement_name=measurement_name, directoryname=directoryname, plotstyle=plotstyle)
+		}
 	}
 	if (resultlist_part$method == 'roc_dynamic') {
 		filename<-paste(basename,"_",resultlist_part$element,"_",'roc_dynamic',sep="")
